# Zeras

A simple tensorflow wrapper


## Description

```
├── Zeras
│   ├── data_batcher.py
│   ├── __init__.py
│   ├── layers.py
│   ├── LICENSE
│   ├── model_graph_template.py
│   ├── model_settings_baseboard.py
│   ├── model_wrapper.py
│   ├── nn.py
│   └── vocab.py
```


## Installation

From PyPI distribution system:

```
pip install Zeras
```


Or from the code:

```
git clone https://github.com/Li-Ming-Fan/Zeras
cd Zeras
make clean install
```


Or just incorporate the directory Zeras/ to your project.



## Usage

For usage of this package, please refer to the demo, or the repositories:

https://github.com/Li-Ming-Fan/text_classification

https://github.com/Li-Ming-Fan/transformer-tensorflow


</br>

## Acknowledgment

We thank the authors and contributors of TensorFlow, Keras, PyTorch and other DL platforms, and other DLearners. The name "Zeras" is a variant from Keras. We use "Z" because it makes the direcory Zeras/ always display in the last (or first) and do not intersect other directories.


